==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALongBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ALongBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6317c727bde5d9de soot_jimple_parser_node_ALongBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLong$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$_init$9ea5740829247a60(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TLong$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$getLong$6b073f7163c8a22c(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$setLong$07e97d8687356b88(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$getLong$6b073f7163c8a22c;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$setLong$07e97d8687356b88;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TLong$object	*(*getLong$6b073f7163c8a22c)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setLong$07e97d8687356b88)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods	soot_jimple_parser_node_ALongBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TLong$object	*__5flong__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs	soot_jimple_parser_node_ALongBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ALongBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ALongBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALongBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALongBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALongBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ALongBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6317c727bde5d9de soot_jimple_parser_node_ALongBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLong$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$_init$9ea5740829247a60(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TLong$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$getLong$6b073f7163c8a22c(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$setLong$07e97d8687356b88(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALongBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$getLong$6b073f7163c8a22c;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$setLong$07e97d8687356b88;
extern _jc_method _jc_soot_jimple_parser_node_ALongBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TLong$object	*(*getLong$6b073f7163c8a22c)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setLong$07e97d8687356b88)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TLong$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vmethods	soot_jimple_parser_node_ALongBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TLong$object	*__5flong__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_refs	soot_jimple_parser_node_ALongBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ALongBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ALongBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALongBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALongBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALongBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ALongBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALongBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALongBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALongBaseTypeNoName_H_ */
